@@ -3,7 +3,7 @@
 # Accelerator for pip, the Python package manager.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: May 16, 2013
+# Last Change: May 17, 2013
 # URL: https://github.com/paylogic/pip-accel
 #
 # TODO Permanently store logs in the pip-accel directory (think about log rotation).
@@ -122,15 +122,15 @@ def main():
                 requirements = unpack_source_dists(arguments)
             except DistributionNotFound:
                 logger.warn("Warning: We don't have all source distributions yet!")
-                requirements = None
-            if requirements is None:
                 download_source_dists(arguments)
-            elif not requirements:
-                logger.info("No unsatisfied requirements found, probably there's nothing to do.")
-                return
             else:
-                if build_binary_dists(requirements) and install_requirements(requirements):
-                    logger.info("Done! Took %s to install %i package%s.", main_timer, len(requirements), '' if len(requirements) == 1 else 's')
+                if not requirements:
+                    logger.info("No unsatisfied requirements found, probably there's nothing to do.")
+                else:
+                    if build_binary_dists(requirements) and install_requirements(requirements):
+                        logger.info("Done! Took %s to install %i package%s.", main_timer, len(requirements), '' if len(requirements) == 1 else 's')
+                    else:
+                        sys.exit(1)
                 return
     except InstallationError:
         # Abort early when pip reports installation errors.
